@@ -28,6 +28,8 @@ class mvp(Base_Technical_Indicator):
 
         super().__init__(symbol, date, period_seconds=period_seconds)
 
+        self.symbol = symbol
+
         self.rule = rule
 
         # Percentage
@@ -76,7 +78,7 @@ class mvp(Base_Technical_Indicator):
         # print(f'acc: {tick.ts} {tick.close} {tick.volume}')
         super().period_accumulate(tick)
 
-        self.mvp_tmp['ts'].append(tick.ts)
+        self.mvp_tmp['ts'].append(tick.datetime)
         self.mvp_tmp['close'].append(tick.close)
         self.mvp_tmp['volume'].append(tick.volume)
         self.volume_current = sum(self.mvp_tmp['volume'])
@@ -158,13 +160,13 @@ class mvp(Base_Technical_Indicator):
         # print(f"{self.burst_volume}, {self.lot_volume}")
         volume = sum(self.mvp_tmp['volume'])
         self.volume_previous = volume
-        close = self.mvp_tmp['close'][-1]
+        close = float(self.mvp_tmp['close'][-1])
         high = max(self.mvp_tmp['close'])
         low = min(self.mvp_tmp['close'])
         burst = 0
         lot = 0
         if self.mvp_index.shape[0] == 0:
-            close = self.mvp_tmp['close'][0]
+            close = float(self.mvp_tmp['close'][0])
             ratio = round(100 * ((close / self.price_yesterday_close) - 1), 2)
             if volume > self.volume_burst_30s:
                 if close < self.price_yesterday_close:
@@ -221,8 +223,12 @@ class mvp(Base_Technical_Indicator):
 
     def check_mvp(self, bool_put: bool = True):
         index = self.mvp_index.shape[0] - 1
-        if 0 < self.price_limit_up_stop_lose <= self.mvp_index['high'].max():
-            return self.w.stop_trading_already
+        try:
+            if 0 < self.price_limit_up_stop_lose <= self.mvp_index['high'].max():
+                return self.w.stop_trading_already
+        except:
+            print(self.mvp_index)
+            exit(0)
 
         if self.volume_moving / 1000 < 1000:
             cprint(f'{int(self.volume_moving / 1000)} volume low', 'blue')
@@ -232,39 +238,39 @@ class mvp(Base_Technical_Indicator):
         if index < 6:
             return False
 
-        if False:
-            volume_burst = self.volume_burst
-            volume_lot = self.volume_lot
-            lot_buy = self.mvp_index.loc[self.mvp_index['lot'] == 1].shape[0]
-            lot_sell = self.mvp_index.loc[self.mvp_index['lot'] == -1].shape[0]
-            burst_buy = self.mvp_index.loc[self.mvp_index['burst'] == 1].shape[0]
-            burst_sell = self.mvp_index.loc[self.mvp_index['burst'] == -1].shape[0]
-            burst_count = self.mvp_index.iloc[2:].loc[self.mvp_index['volume'] >= volume_burst].shape[0]
-            lot_count = self.mvp_index.loc[self.mvp_index['volume'] >= volume_lot].shape[0]
-            last_burst_buy = self.mvp_index.iloc[-10:].loc[self.mvp_index['burst'] == 1].shape[0]
-            last_burst_sell = self.mvp_index.iloc[-10:].loc[self.mvp_index['burst'] == -1].shape[0]
-            price_min = self.mvp_index['low'].min()
-            if burst_count > 0 and burst_buy > -1 and burst_sell < 1 and price_min >= self.price_open * 0.99:
-                self.count_volume_burst = burst_count
-                self.index_price_enter = index
-                self.price_enter = self.mvp_index.iloc[index]['close']
-                return True
-                if burst_buy > 0 and burst_sell - burst_buy <= 0 and burst_count < 10:
-                    self.index_price_enter = index
-                    self.price_enter = self.mvp_index.iloc[index]['close']
-                    print(f'count:{burst_count} buy:{burst_buy} sell:{burst_sell}')
-                    return True
-                else:
-                    return self.w.stop_trading_already
-                if not self.bool_skip_burst:
-                    if burst_sell < burst_buy:
-                        if last_burst_sell > 0:
-                            self.bool_skip_burst = True
-                            return False
-                        cprint(f'symbol:{self.symbol},count:{burst_count}, buy:{burst_buy}, sell:{burst_sell}, last:{last_burst_buy}, burst:{self.volume_burst_30s}', 'red')
-                        return self.w.stop_trading_already
-            else:
-                return self.w.stop_trading_already
+        # if False:
+        #     volume_burst = self.volume_burst
+        #     volume_lot = self.volume_lot
+        #     lot_buy = self.mvp_index.loc[self.mvp_index['lot'] == 1].shape[0]
+        #     lot_sell = self.mvp_index.loc[self.mvp_index['lot'] == -1].shape[0]
+        #     burst_buy = self.mvp_index.loc[self.mvp_index['burst'] == 1].shape[0]
+        #     burst_sell = self.mvp_index.loc[self.mvp_index['burst'] == -1].shape[0]
+        #     burst_count = self.mvp_index.iloc[2:].loc[self.mvp_index['volume'] >= volume_burst].shape[0]
+        #     lot_count = self.mvp_index.loc[self.mvp_index['volume'] >= volume_lot].shape[0]
+        #     last_burst_buy = self.mvp_index.iloc[-10:].loc[self.mvp_index['burst'] == 1].shape[0]
+        #     last_burst_sell = self.mvp_index.iloc[-10:].loc[self.mvp_index['burst'] == -1].shape[0]
+        #     price_min = self.mvp_index['low'].min()
+        #     if burst_count > 0 and burst_buy > -1 and burst_sell < 1 and price_min >= self.price_open * 0.99:
+        #         self.count_volume_burst = burst_count
+        #         self.index_price_enter = index
+        #         self.price_enter = self.mvp_index.iloc[index]['close']
+        #         return True
+        #         if burst_buy > 0 and burst_sell - burst_buy <= 0 and burst_count < 10:
+        #             self.index_price_enter = index
+        #             self.price_enter = self.mvp_index.iloc[index]['close']
+        #             print(f'count:{burst_count} buy:{burst_buy} sell:{burst_sell}')
+        #             return True
+        #         else:
+        #             return self.w.stop_trading_already
+        #         if not self.bool_skip_burst:
+        #             if burst_sell < burst_buy:
+        #                 if last_burst_sell > 0:
+        #                     self.bool_skip_burst = True
+        #                     return False
+        #                 cprint(f'symbol:{self.symbol},count:{burst_count}, buy:{burst_buy}, sell:{burst_sell}, last:{last_burst_buy}, burst:{self.volume_burst_30s}', 'red')
+        #                 return self.w.stop_trading_already
+        #     else:
+        #         return self.w.stop_trading_already
 
         if bool_put:
             cur_mvp = self.mvp_index.iloc[index]
@@ -350,7 +356,7 @@ class mvp(Base_Technical_Indicator):
         return False
 
     def draw(self, symbol, date, filename):
-        # super(mvp, self).draw(symbol, date, filename)
+        super(mvp, self).draw(symbol, date, filename)
         folder = '../png/png_test'
         if not os.path.exists(folder):
             os.makedirs(folder)
